@@ -10,7 +10,7 @@ describe 'watcher::db::postgresql' do
     { :password => 'watcherpass' }
   end
 
-  shared_examples_for 'watcher-db-postgresql' do
+  shared_examples_for 'watcher::db::postgresql' do
     context 'with only required parameters' do
       let :params do
         required_params
@@ -33,10 +33,14 @@ describe 'watcher::db::postgresql' do
   }).each do |os,facts|
     context "on #{os}" do
       let (:facts) do
-        facts.merge!(OSDefaults.get_facts({ :concat_basedir => '/var/lib/puppet/concat' }))
+        facts.merge!(OSDefaults.get_facts({
+          # puppet-postgresql requires the service_provider fact provided by
+          # puppetlabs-postgresql.
+          :service_provider => 'systemd'
+        }))
       end
 
-      it_behaves_like 'watcher-db-postgresql'
+      it_behaves_like 'watcher::db::postgresql'
     end
   end
 end
