@@ -9,8 +9,9 @@ describe 'watcher::wsgi::apache' do
         :bind_port                   => 9322,
         :group                       => 'watcher',
         :path                        => '/',
+        :priority                    => 10,
         :servername                  => facts[:fqdn],
-        :ssl                         => true,
+        :ssl                         => false,
         :threads                     => 1,
         :user                        => 'watcher',
         :workers                     => facts[:os_workers],
@@ -19,27 +20,33 @@ describe 'watcher::wsgi::apache' do
         :wsgi_script_dir             => platform_params[:wsgi_script_path],
         :wsgi_script_file            => 'app',
         :wsgi_script_source          => platform_params[:wsgi_script_source],
-        :access_log_file             => false,
-        :access_log_format           => false,
+        :headers                     => nil,
+        :request_headers             => nil,
         :custom_wsgi_process_options => {},
+        :access_log_file             => nil,
+        :access_log_pipe             => nil,
+        :access_log_syslog           => nil,
+        :access_log_format           => nil,
+        :error_log_file              => nil,
+        :error_log_pipe              => nil,
+        :error_log_syslog            => nil,
       )}
     end
 
-    context 'when overriding parameters using different ports' do
+    context 'when overriding parameters' do
       let :params do
         {
           :servername                  => 'dummy.host',
           :bind_host                   => '10.42.51.1',
           :port                        => 12345,
-          :ssl                         => false,
+          :ssl                         => true,
           :wsgi_process_display_name   => 'watcher',
           :workers                     => 37,
-          :access_log_file             => '/var/log/httpd/access_log',
-          :access_log_format           => 'some format',
-          :error_log_file              => '/var/log/httpd/error_log',
           :custom_wsgi_process_options => {
             'python_path' => '/my/python/path',
           },
+          :headers                     => ['set X-XSS-Protection "1; mode=block"'],
+          :request_headers             => ['set Content-Type "application/json"'],
         }
       end
       it { is_expected.to contain_class('watcher::params') }
@@ -49,7 +56,7 @@ describe 'watcher::wsgi::apache' do
         :group                       => 'watcher',
         :path                        => '/',
         :servername                  => 'dummy.host',
-        :ssl                         => false,
+        :ssl                         => true,
         :threads                     => 1,
         :user                        => 'watcher',
         :workers                     => 37,
@@ -59,14 +66,77 @@ describe 'watcher::wsgi::apache' do
         :wsgi_script_dir             => platform_params[:wsgi_script_path],
         :wsgi_script_file            => 'app',
         :wsgi_script_source          => platform_params[:wsgi_script_source],
-        :access_log_file             => '/var/log/httpd/access_log',
-        :access_log_format           => 'some format',
-        :error_log_file              => '/var/log/httpd/error_log',
+        :headers                     => ['set X-XSS-Protection "1; mode=block"'],
+        :request_headers             => ['set Content-Type "application/json"'],
         :custom_wsgi_process_options => {
           'python_path' => '/my/python/path',
         },
       )}
     end
+
+    context 'with custom access logging' do
+      let :params do
+        {
+          :access_log_format => 'foo',
+          :access_log_syslog => 'syslog:local0',
+          :error_log_syslog  => 'syslog:local1',
+        }
+      end
+
+      it { should contain_openstacklib__wsgi__apache('watcher_wsgi').with(
+        :access_log_format => params[:access_log_format],
+        :access_log_syslog => params[:access_log_syslog],
+        :error_log_syslog  => params[:error_log_syslog],
+      )}
+    end
+
+    context 'with access_log_file' do
+      let :params do
+        {
+          :access_log_file => '/path/to/file',
+        }
+      end
+
+      it { should contain_openstacklib__wsgi__apache('watcher_wsgi').with(
+        :access_log_file => params[:access_log_file],
+      )}
+    end
+
+    context 'with access_log_pipe' do
+      let :params do
+        {
+          :access_log_pipe => 'pipe',
+        }
+      end
+
+      it { should contain_openstacklib__wsgi__apache('watcher_wsgi').with(
+        :access_log_pipe => params[:access_log_pipe],
+      )}
+    end
+
+    context 'with error_log_file' do
+      let :params do
+        {
+          :error_log_file => '/path/to/file',
+        }
+      end
+
+      it { should contain_openstacklib__wsgi__apache('watcher_wsgi').with(
+        :error_log_file => params[:error_log_file],
+      )}
+    end
+
+    context 'with error_log_pipe' do
+      let :params do
+        {
+          :error_log_pipe => 'pipe',
+        }
+      end
+
+      it { should contain_openstacklib__wsgi__apache('watcher_wsgi').with(
+        :error_log_pipe => params[:error_log_pipe],
+      )}
+    end
   end
 
   on_supported_os({
